// Sample data for the top populous countries
const data = [
  { country: "China", population: 1439323776 },
  { country: "India", population: 1380004385 },
  { country: "United States", population: 331002651 },
  { country: "Indonesia", population: 273523615 },
  { country: "Pakistan", population: 220892340 }
  // Add more countries as needed
];

// Set up dimensions for the chart
const margin = { top: 30, right: 30, bottom: 70, left: 60 };
const width = 600 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// Create an SVG element and append it to the chart div
const svg = d3.select("#chart")
  .append("svg")
  .attr("width", width + margin.left + margin.right)
  .attr("height", height + margin.top + margin.bottom)
  .append("g")
  .attr("transform", `translate(${margin.left},${margin.top})`);

// Create scales for x and y axes
const xScale = d3.scaleBand()
  .domain(data.map(d => d.country))
  .range([0, width])
  .padding(0.2);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(data, d => d.population)])
  .range([height, 0]);

// Create x and y axes
const xAxis = d3.axisBottom(xScale);
const yAxis = d3.axisLeft(yScale);

// Append x and y axes to the SVG element
svg.append("g")
  .attr("class", "x-axis")
  .attr("transform", `translate(0, ${height})`)
  .call(xAxis);

svg.append("g")
  .attr("class", "y-axis")
  .call(yAxis);

// Create the bars
svg.selectAll(".bar")
  .data(data)
  .enter()
  .append("rect")
  .attr("class", "bar")
  .attr("x", d => xScale(d.country))
  .attr("y", d => yScale(d.population))
  .attr("width", xScale.bandwidth())
  .attr("height", d => height - yScale(d.population));

// Add labels to the bars
svg.selectAll(".bar-label")
  .data(data)
  .enter()
  .append("text")
  .attr("class", "bar-label")
  .attr("x", d => xScale(d.country) + xScale.bandwidth() / 2)
  .attr("y", d => yScale(d.population) - 5)
  .attr("text-anchor", "middle")
  .text(d => d.population);

// Add a title to the chart
svg.append("text")
  .attr("class", "chart-title")
  .attr("x", width / 2)
  .attr("y", -margin.top / 2)
  .attr("text-anchor", "middle")
  .text("Top Populous Countries");

